@@ -39,8 +39,11 @@ title=*SH_bn* section=1 repnl=\040
 	*SH_bn* [-hHVvF] [-A names]
 @tl;dr
 		@(code)@
+	~$ *SH_bn* > funcs.sh
+	
+	--src.sh
 	#!/bin/sh
-	eval "$(*SH_bn* -v 2 -F)"
+	. ./funcs.sh
 	_eq 1 1
 	_neq 1 1 'write anymsg at last arg'
 	ls
@@ -57,18 +60,18 @@ title=*SH_bn* section=1 repnl=\040
 	-v level: verbose level. 0/1/2 == quite/normal/verbose. output to stderr
 	-F: fallthrough. stops running if detect assert error in default
 	-A names: change assert alias names. set 5 fields --
-	  eg) ~$ *SH_bn* -A'' '_eq _neq _suc _fail _res' '' #same as default --
-	  eg) ~$ *SH_bn* -A'' 'aa bb cc dd zz' '' #'_''eq 1 2' changes to 'aa 1 2'
+	  eg) ~$ *SH_bn* -A '_eq _neq _suc _fail _res'  #same as default --
+	  eg) ~$ *SH_bn* -A 'aa bb cc dd zz'  #` _eq 1 2` changes to `aa 1 2`
 	@()
 @_desc
-	'*SH_bn*' outputs assert alias, support functions and assert count vars.
+	`*SH_bn*` outputs assert alias, support functions and assert count vars.
 	core api is alias.
 	@(list)
-	  ' _eq': take 2 args and test [ ag1 = ag2 ]
-	  ' _neq': take 2 args and test [ ag1 != ag2 ]
-	  ' _suc': take no arg. same as' _eq $? 0'
-	  ' _fail': take no arg. same as' _neq $? 0'
-	  ' _res': this isnt assert. output the result and return. if 5 assert
+	  ` _eq`: takes 2 args and test [ ag1 = ag2 ]
+	  ` _neq`: takes 2 args and test [ ag1 != ag2 ]
+	  ` _suc`: takes no arg. same as` _eq $? 0`
+	  ` _fail`: takes no arg. same as` _neq $? 0`
+	  ` _res`: this isnt assert. output the result and return. if 5 assert
 			failed, $? == 5.
 	@()--
 	upper 5 takes additional 1 arg for memo/msg. eg) _suc  this_is_f1_test --
@@ -78,19 +81,19 @@ title=*SH_bn* section=1 repnl=\040
 	  ~$ *SH_bn*	#>> shunit_eq(){ abc...}
 	  ~$ *SH_bn* -F	#>> shunit_eq(){ xyz...}
 	@()--
-	'*** CAUTION ***'--
+	--- --
 	dont eval in compound commands, (), {}, func()(), func(){} etc.
 		@(code)--
-	--good            |   ---NG1               |  ---NG2
-	#!/bin/sh         |   #!/bin/sh            |  #!/bin/sh         
-	eval "$(shnit_m)" |   (                    |  testf(){
-	(                 |     eval "$(shunit_m)" |    eval "$(shunit_m)"
-	    _eq 1 1       |     _eq 1 1            |    _eq 1 1
-	    _res          |     _res               |    _res
-	)                 |   )                    |  }
-	                  |                        |  testf
+	--good             |  ---NG1               |  ---NG2
+	#!/bin/sh          |  #!/bin/sh            |  #!/bin/sh         
+	eval "$(shunit_m)" |  (                    |  testf(){
+	(                  |    eval "$(shunit_m)" |    eval "$(shunit_m)"
+	    _eq 1 1        |    _eq 1 1            |    _eq 1 1
+	    _res           |    _res               |    _res
+	)                  |  )                    |  }
+	                   |                       |  testf
 		@()--
-	alias substitution should work as C-lang preprocesser and the scope must 
+	alias substitution should work as C-lang macros and the scope must 
 	be the same as local vars in posix-shell. --
 	(https://pubs.opengroup.org/onlinepubs/9699919799/utilities/alias.html)--
 	--
@@ -102,7 +105,7 @@ title=*SH_bn* section=1 repnl=\040
 	sh -c '(alias abc='ls'; alias ; abc)'
 	# sh == bash --posix / dash / ksh / busybox sh 
 		@()--
-	allmost all shells works fine if eval shunit in `base` process, tread as
+	allmost all shells works fine if eval shunit_m in base process, tread as
 	C-lang #define delective.
 
 @EXIT_STATUS
@@ -121,25 +124,21 @@ title=*SH_bn* section=1 repnl=\040
 	  num=$(($1+$2))
 	}
 	
-	### run main or testcode
+	## run main
 	# src_main "$@"
 	# exit $?
 	
-	cmd="$(*SH_bn*)"		#>> output alias, funcs code
+	## run testcode
+	cmd="$(*SH_bn*)"
 	eval "$cmd"		#>> you can check with 'echo "$cmd"'
-	
-	# testcode
-	{
-	  echo "test_start" >&3
-	  f1	;_fail
-	  f1 1 2	;_eq 3 $num
-	} 3>&1 >buf.log 2>&1 ||
-		(tail buf.log;echo "--test FAILED";exit 1)>/dev/stderr
+
+	f1	;_fail
+	f1 1 2	;_eq 3 $num
 	_res
 	echo "--test suc"
 
 	--test_run 
-	~$ dash src.sh		#>> output result
+	~$ dash src.sh
 		@()--
 	--
 
@@ -201,8 +200,8 @@ title=*SH_bn* section=1 repnl=\040
 @copyright
 	Copyright (C) 2021 Momi-g --
 	License GPLv3+ <https://gnu.org/licenses/gpl.html>
-@_ver 2021-09-12 v1.0.2
-@_see 'shunit2(1), shellspec'
+@_ver 2021-10-12 v1.0.3
+@_see `shunit2(1), shellspec`
 #SH_docE
 EEE
 #SH_ED
@@ -216,14 +215,15 @@ cat << 'EEE'
 HowTo (*SH_bn* - posix & portable shell xunit)
 opt: -v(erbose) -F(all) -A(lias), -hHV(hHelp,version)
 ---
-eg) #!/bin/sh
-    eval "$(*SH_bn* -v 2 -F)"	#>> output alias, funcs code
+eg) ~$ *SH_bn* -v2 > funcs.sh
 
-    _eq 1 1	#>> assert $1 = $2
-    _neq 1 1 msg	#>> assert $1 != $2 
-    ls
-    _fail	#>> assert $? != 0
-    _res	# >> output result + return rc. rc is failed assert cnt.
+	#!/bin/sh
+	. ./funcs.sh
+	_eq 1 1	#>> assert $1 = $2
+	_neq 1 1 msg	#>> assert $1 != $2 
+	ls
+	_fail	#>> assert $? != 0
+	_res	# >> output result + return rc. rc is failed assert cnt.
 	
  ..*SH_bn* drops assert alias, funcs and test count vars.
  assert: _eq, _neq, _suc, _fail, _res(report)
@@ -486,6 +486,10 @@ cat << EEE >/dev/null
 /*
  change log
  --
+2021-10-12  Momi-g	<dmy@dmy.dmy>
+
+	* *SH_bn* (doc): improve doc. v1.0.3
+
 2021-09-12  Momi-g	<dmy@dmy.dmy>
 
 	* *SH_bn* (assert): add ag3 for assert msg. v1.0.2
